module BigMarkerClient
  module Models
    ##
    # for supported values for time_zone please compare [the documentation](https://docs.bigmarker.com/#time-zones)
    class Conference < Base
      attr_accessor :id, :title, :event_type, :display_language, :meeting_mode, :type, :conference_copy_id,
                    :master_webinar_id, :max_attendance, :purpose, :start_time, :duration_minutes, :conference_address,
                    :custom_event_id, :channel_id, :webcast_mode, :end_time, :moderator_open_time, :audience_open_time,
                    :first_admin_enter_time, :manual_end_time, :privacy, :exit_url, :enable_registration_email,
                    :enable_knock_to_enter, :send_reminder_emails_to_presenters, :review_emails,
                    :poll_results, :enable_ie_safari, :enable_twitter, :auto_invite_all_channel_members,
                    :send_cancellation_email, :show_reviews, :registration_required_to_view_recording,
                    :who_can_watch_recording, :show_handout_on_page, :background_image_url, :room_logo, :agenda_topics,
                    :disclaimer, :recorded, :recording_url, :recording_iframe,
                    # for conference creation
                    :sub_url, :enable_dial_in, :time_zone, :schedule_type, :recurring_start_times,
                    :presenter_advanced_enter_time, :attendee_advanced_enter_time, :webinar_format,
                    :registration_conf_emails, :send_notification_emails_to_presenters, :webhook_url, :channel_admin_id,
                    :free_for_all, :room_type, :room_sub_title

      attr_reader :dial_in_information, :preload_files, :presenters, :webinar_stats, :associated_series

      # differences between creation and retrieval, use creation as leading (oh well)
      alias can_view_poll_results poll_results
      alias can_view_poll_results= poll_results=
      alias duration duration_minutes
      alias duration= duration_minutes=
      alias enable_review_emails review_emails
      alias enable_review_emails= review_emails=
      alias language display_language
      alias language= display_language=
      alias copy_webinar_id conference_copy_id
      alias copy_webinar_id= conference_copy_id=

      def dial_in_information=(dial_in_hash)
        @dial_in_information = if dial_in_hash.nil? || !dial_in_hash.is_a?(Hash)
                                 nil
                               else
                                 DialInInformation.new(dial_in_hash)
                               end
      end

      def preload_files=(file_array)
        @preload_files = if file_array.nil? || !file_array.is_a?(Array) || file_array.empty?
                           []
                         else
                           file_array.map { |file_hash| PreloadFile.new(file_hash) }
                         end
      end

      def presenters=(presenter_array)
        @presenters = if presenter_array.nil? || !presenter_array.is_a?(Array) || presenter_array.empty?
                        []
                      else
                        presenter_array.map { |presenter_hash| Presenter.new(presenter_hash) }
                      end
      end

      def webinar_stats=(webinar_stats_hash)
        @webinar_stats = if webinar_stats_hash.nil? || !webinar_stats_hash.is_a?(Hash)
                           nil
                         else
                           WebinarStats.new(webinar_stats_hash)
                         end
      end

      def associated_series=(series_array)
        @associated_series = if series_array.nil? || !series_array.is_a?(Array) || series_array.empty?
                               []
                             else
                               # TODO: identify element
                               series_array.map { |series_hash| series_hash.map { |k, v| "#{k}: #{v}" } }
                             end
      end
    end
  end
end
